window.Gleam.initSearch([{"doc":"glenv","title":"glenv","content":"# glenv\n\n[![Package Version](https://img.shields.io/hexpm/v/glenv)](https://hex.pm/packages/glenv)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glenv/)\n\nType-safe environment variables for Gleam.\n\nAccessing environment variables doesn&#39;t give us the type of safety guarantees we&#39;d like in a langauge like Gleam. glenv aims to guarantee that each environment variable is of the correct type AND is present.\n\n```sh\ngleam add glenv\n```\n```gleam\nimport gleam/decode\nimport glenv\n\npub type MyEnv {\n  MyEnv(hello: String, foo: Float, count: Int, is_on: Bool)\n}\n\npub fn main() {\n  let definitions = [\n    #(&quot;HELLO&quot;, glenv.String),\n    #(&quot;FOO&quot;, glenv.Float),\n    #(&quot;COUNT&quot;, glenv.Int),\n    #(&quot;IS_ON&quot;, glenv.Bool),\n  ]\n\n  let decoder =\n    decode.into({\n      use hello &lt;- decode.parameter\n      use foo &lt;- decode.parameter\n      use count &lt;- decode.parameter\n      use is_on &lt;- decode.parameter\n\n      MyEnv(hello: hello, foo: foo, count: count, is_on: is_on)\n    })\n    |&gt; decode.field(&quot;HELLO&quot;, decode.string)\n    |&gt; decode.field(&quot;FOO&quot;, decode.float)\n    |&gt; decode.field(&quot;COUNT&quot;, decode.int)\n    |&gt; decode.field(&quot;IS_ON&quot;, decode.bool)\n\n  let assert Ok(env) = glenv.load(decoder, definitions)\n\n  env.hello == &quot;hello&quot;\n  env.foo == 1.0\n  env.count == 1\n  env.is_on == True\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glenv&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"internal/parse","title":"bool","content":"pub fn bool(\n  key: String,\n  value: String,\n) -&gt; Result(#(String, Dynamic), Nil)\n\nSynonyms:\ninternal/parse.bool\ninternal/parse bool","url":"internal/parse.html#bool"},{"doc":"internal/parse","title":"float","content":"pub fn float(\n  key: String,\n  value: String,\n) -&gt; Result(#(String, Dynamic), Nil)\n\nSynonyms:\ninternal/parse.float\ninternal/parse float","url":"internal/parse.html#float"},{"doc":"internal/parse","title":"int","content":"pub fn int(\n  key: String,\n  value: String,\n) -&gt; Result(#(String, Dynamic), Nil)\n\nSynonyms:\ninternal/parse.int\ninternal/parse int","url":"internal/parse.html#int"},{"doc":"internal/parse","title":"string","content":"pub fn string(\n  key: String,\n  value: String,\n) -&gt; Result(#(String, Dynamic), Nil)\n\nSynonyms:\ninternal/parse.string\ninternal/parse string","url":"internal/parse.html#string"},{"doc":"internal/parse","title":"internal/parse","content":"","url":"internal/parse.html"},{"doc":"glenv","title":"Definition","content":"pub type Definition =\n  #(String, Type)\n Definition represents a single environment variable, from key to type.\n\nSynonyms:\nglenv.Definition\nglenv Definition","url":"glenv.html#Definition"},{"doc":"glenv","title":"EnvError","content":"pub type EnvError {\n  MissingKeyError(key: String)\n  InvalidEnvValue(key: String, expected: Type)\n  ValidationError(errors: List(dynamic.DecodeError))\n}\n EnvError represents an error that can occur when loading the environment.\nMissingKeyError(key: String)\n\n\nInvalidEnvValue(key: String, expected: Type)\n\n\nValidationError(errors: List(dynamic.DecodeError))\n\n\nSynonyms:\nglenv.EnvError\nglenv EnvError","url":"glenv.html#EnvError"},{"doc":"glenv","title":"Type","content":"pub type Type {\n  Bool\n  Float\n  Int\n  String\n}\n Type represents the type of an environment variable.\n This dictates how the environment variable is parsed.\nBool\n\n\nFloat\n\n\nInt\n\n\nString\n\n\nSynonyms:\nglenv.Type\nglenv Type","url":"glenv.html#Type"},{"doc":"glenv","title":"load","content":"pub fn load(\n  decoder: Decoder(a),\n  definitions: List(#(String, Type)),\n) -&gt; Result(a, EnvError)\n Load parses the environment variables and returns a Result containing the environment.\n Takes a decoder from the gleam/decode library and a list of definitions.\n \n ## Examples\n\n \n type Env {\n   Env(hello: String, foo: Float, count: Int, is_on: Bool)\n }\n\n let definitions = [\n   #(&quot;HELLO&quot;, glenv.String),\n   #(&quot;FOO&quot;, glenv.Float),\n   #(&quot;COUNT&quot;, glenv.Int),\n   #(&quot;IS_ON&quot;, glenv.Bool),\n ]\n\n let decoder =\n   decode.into({\n     use hello &lt;- decode.parameter\n     use foo &lt;- decode.parameter\n     use count &lt;- decode.parameter\n     use is_on &lt;- decode.parameter\n\n     Env(hello: hello, foo: foo, count: count, is_on: is_on)\n   })\n   |&gt; decode.field(&quot;HELLO&quot;, decode.string)\n   |&gt; decode.field(&quot;FOO&quot;, decode.float)\n   |&gt; decode.field(&quot;COUNT&quot;, decode.int)\n   |&gt; decode.field(&quot;IS_ON&quot;, decode.bool)\n\n let assert Ok(env) = glenv.load(decoder, definitions)\n\n env.hello // &quot;world&quot;\n env.foo // 1.0\n env.count // 1\n env.is_on // True\n \nSynonyms:\nglenv.load\nglenv load","url":"glenv.html#load"},{"doc":"glenv","title":"glenv","content":" glenv is a library for type-sfe environment variable access.\n","url":"glenv.html"},{"doc":"internal/parse_test","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ninternal/parse_test.main\ninternal/parse_test main","url":"internal/parse_test.html#main"},{"doc":"internal/parse_test","title":"parse_bool_test","content":"pub fn parse_bool_test() -&gt; Nil\n\nSynonyms:\ninternal/parse_test.parse_bool_test\ninternal/parse_test parse_bool_test","url":"internal/parse_test.html#parse_bool_test"},{"doc":"internal/parse_test","title":"parse_float_test","content":"pub fn parse_float_test() -&gt; Nil\n\nSynonyms:\ninternal/parse_test.parse_float_test\ninternal/parse_test parse_float_test","url":"internal/parse_test.html#parse_float_test"},{"doc":"internal/parse_test","title":"parse_int_test","content":"pub fn parse_int_test() -&gt; Nil\n\nSynonyms:\ninternal/parse_test.parse_int_test\ninternal/parse_test parse_int_test","url":"internal/parse_test.html#parse_int_test"},{"doc":"internal/parse_test","title":"parse_string_test","content":"pub fn parse_string_test() -&gt; Nil\n\nSynonyms:\ninternal/parse_test.parse_string_test\ninternal/parse_test parse_string_test","url":"internal/parse_test.html#parse_string_test"},{"doc":"internal/parse_test","title":"internal/parse_test","content":"","url":"internal/parse_test.html"}]);